'''
    author: rkopeinig
    script: Seasonal Components
    description: Bunch of algorithms within seasonal or cyclic components.
                 See Proba-V Time-Series Analysis Toolbox Poster.
    version: 0.1
'''

import pandas as pd
from statsmodels.tsa.stattools import acf, pacf
from scipy.signal import correlate

def crosscorrelation(series_1, series_2):
    """Cross-correlate two Pandas Series

        :param series_1: First One-dimensional ndarray with axis labels including Time-Series.
        :type series_1: pandas.core.series.Series

        :param series2: Second One-dimensional ndarray with axis labels including Time-Series.
        :type series_2: pandas.core.series.Series

        :return: Series containing a subset of the disrete linear cross-correlation of series_1 and series_2.
        :rtype: pandas.core.series.Series

    """
    x = series_1.values
    y = series_2.values
    return pd.Series(correlate(x, y, mode='same'), index=series_1.index)


def autocorrelation(series):
    """Auto Correlation of Pandas Series

            :param series: First One-dimensional ndarray with axis labels including Time-Series.
            :type series: pandas.core.series.Series

            :return: Series of auto correlation results without index
            :rtype: pandas.core.series.Series

        """
    x=series.values
    _acf = pd.Series(acf(x))
    _acf.index+=1
    return _acf


def partial_autocorrelation(series):
    """Partial Auto Correlation of Pandas Series

                :param series: First One-dimensional ndarray with axis labels including Time-Series.
                :type series: pandas.core.series.Series

                :return: Series of partial auto correlation results without index
                :rtype: pandas.core.series.Series

            """
    x=series.values
    _pacf = pd.Series(pacf(x))
    _pacf.index+=1
    return _pacf

